
# Slot: edge_list_may_contain_duplicates


Whether the edge list may contain duplicates. If the edge list surely DOES NOT contain duplicates, a validation step may be skipped. By default, it is assumed that the edge list may contain duplicates.

URI: [https://w3id.org/neat/ensmallenRunConfig__edge_list_may_contain_duplicates](https://w3id.org/neat/ensmallenRunConfig__edge_list_may_contain_duplicates)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
